from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MconfigCls:
	"""Mconfig commands group definition. 101 total commands, 54 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mconfig", core, parent)

	@property
	def adb1(self):
		"""adb1 commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adb1'):
			from .Adb1 import Adb1Cls
			self._adb1 = Adb1Cls(self._core, self._cmd_group)
		return self._adb1

	@property
	def adb3(self):
		"""adb3 commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adb3'):
			from .Adb3 import Adb3Cls
			self._adb3 = Adb3Cls(self._core, self._cmd_group)
		return self._adb3

	@property
	def adb4(self):
		"""adb4 commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adb4'):
			from .Adb4 import Adb4Cls
			self._adb4 = Adb4Cls(self._core, self._cmd_group)
		return self._adb4

	@property
	def aid(self):
		"""aid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aid'):
			from .Aid import AidCls
			self._aid = AidCls(self._core, self._cmd_group)
		return self._aid

	@property
	def apDesignator(self):
		"""apDesignator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apDesignator'):
			from .ApDesignator import ApDesignatorCls
			self._apDesignator = ApDesignatorCls(self._core, self._cmd_group)
		return self._apDesignator

	@property
	def atcHeight(self):
		"""atcHeight commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atcHeight'):
			from .AtcHeight import AtcHeightCls
			self._atcHeight = AtcHeightCls(self._core, self._cmd_group)
		return self._atcHeight

	@property
	def atuSelector(self):
		"""atuSelector commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atuSelector'):
			from .AtuSelector import AtuSelectorCls
			self._atuSelector = AtuSelectorCls(self._core, self._cmd_group)
		return self._atuSelector

	@property
	def cwaThreshold(self):
		"""cwaThreshold commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cwaThreshold'):
			from .CwaThreshold import CwaThresholdCls
			self._cwaThreshold = CwaThresholdCls(self._core, self._cmd_group)
		return self._cwaThreshold

	@property
	def dfLocation(self):
		"""dfLocation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dfLocation'):
			from .DfLocation import DfLocationCls
			self._dfLocation = DfLocationCls(self._core, self._cmd_group)
		return self._dfLocation

	@property
	def dg(self):
		"""dg commands group. 12 Sub-classes, 0 commands."""
		if not hasattr(self, '_dg'):
			from .Dg import DgCls
			self._dg = DgCls(self._core, self._cmd_group)
		return self._dg

	@property
	def dlOffset(self):
		"""dlOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlOffset'):
			from .DlOffset import DlOffsetCls
			self._dlOffset = DlOffsetCls(self._core, self._cmd_group)
		return self._dlOffset

	@property
	def fdb(self):
		"""fdb commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_fdb'):
			from .Fdb import FdbCls
			self._fdb = FdbCls(self._core, self._cmd_group)
		return self._fdb

	@property
	def fdBlock(self):
		"""fdBlock commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdBlock'):
			from .FdBlock import FdBlockCls
			self._fdBlock = FdBlockCls(self._core, self._cmd_group)
		return self._fdBlock

	@property
	def fdsState(self):
		"""fdsState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fdsState'):
			from .FdsState import FdsStateCls
			self._fdsState = FdsStateCls(self._core, self._cmd_group)
		return self._fdsState

	@property
	def flaa(self):
		"""flaa commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_flaa'):
			from .Flaa import FlaaCls
			self._flaa = FlaaCls(self._core, self._cmd_group)
		return self._flaa

	@property
	def frcLink(self):
		"""frcLink commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frcLink'):
			from .FrcLink import FrcLinkCls
			self._frcLink = FrcLinkCls(self._core, self._cmd_group)
		return self._frcLink

	@property
	def fvaa(self):
		"""fvaa commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fvaa'):
			from .Fvaa import FvaaCls
			self._fvaa = FvaaCls(self._core, self._cmd_group)
		return self._fvaa

	@property
	def gcid(self):
		"""gcid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gcid'):
			from .Gcid import GcidCls
			self._gcid = GcidCls(self._core, self._cmd_group)
		return self._gcid

	@property
	def gpAngle(self):
		"""gpAngle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gpAngle'):
			from .GpAngle import GpAngleCls
			self._gpAngle = GpAngleCls(self._core, self._cmd_group)
		return self._gpAngle

	@property
	def gsaDesignator(self):
		"""gsaDesignator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gsaDesignator'):
			from .GsaDesignator import GsaDesignatorCls
			self._gsaDesignator = GsaDesignatorCls(self._core, self._cmd_group)
		return self._gsaDesignator

	@property
	def gsrReceivers(self):
		"""gsrReceivers commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gsrReceivers'):
			from .GsrReceivers import GsrReceiversCls
			self._gsrReceivers = GsrReceiversCls(self._core, self._cmd_group)
		return self._gsrReceivers

	@property
	def kcGlonass(self):
		"""kcGlonass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kcGlonass'):
			from .KcGlonass import KcGlonassCls
			self._kcGlonass = KcGlonassCls(self._core, self._cmd_group)
		return self._kcGlonass

	@property
	def kcGps(self):
		"""kcGps commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kcGps'):
			from .KcGps import KcGpsCls
			self._kcGps = KcGpsCls(self._core, self._cmd_group)
		return self._kcGps

	@property
	def kdGlonass(self):
		"""kdGlonass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kdGlonass'):
			from .KdGlonass import KdGlonassCls
			self._kdGlonass = KdGlonassCls(self._core, self._cmd_group)
		return self._kdGlonass

	@property
	def kdGps(self):
		"""kdGps commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kdGps'):
			from .KdGps import KdGpsCls
			self._kdGps = KdGpsCls(self._core, self._cmd_group)
		return self._kdGps

	@property
	def kpGlonass(self):
		"""kpGlonass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kpGlonass'):
			from .KpGlonass import KpGlonassCls
			self._kpGlonass = KpGlonassCls(self._core, self._cmd_group)
		return self._kpGlonass

	@property
	def kpGps(self):
		"""kpGps commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_kpGps'):
			from .KpGps import KpGpsCls
			self._kpGps = KpGpsCls(self._core, self._cmd_group)
		return self._kpGps

	@property
	def lfLocation(self):
		"""lfLocation commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_lfLocation'):
			from .LfLocation import LfLocationCls
			self._lfLocation = LfLocationCls(self._core, self._cmd_group)
		return self._lfLocation

	@property
	def lmVariation(self):
		"""lmVariation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lmVariation'):
			from .LmVariation import LmVariationCls
			self._lmVariation = LmVariationCls(self._core, self._cmd_group)
		return self._lmVariation

	@property
	def location(self):
		"""location commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_location'):
			from .Location import LocationCls
			self._location = LocationCls(self._core, self._cmd_group)
		return self._location

	@property
	def mt2State(self):
		"""mt2State commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mt2State'):
			from .Mt2State import Mt2StateCls
			self._mt2State = Mt2StateCls(self._core, self._cmd_group)
		return self._mt2State

	@property
	def mt4State(self):
		"""mt4State commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mt4State'):
			from .Mt4State import Mt4StateCls
			self._mt4State = Mt4StateCls(self._core, self._cmd_group)
		return self._mt4State

	@property
	def muDistance(self):
		"""muDistance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_muDistance'):
			from .MuDistance import MuDistanceCls
			self._muDistance = MuDistanceCls(self._core, self._cmd_group)
		return self._muDistance

	@property
	def nfdBlocks(self):
		"""nfdBlocks commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nfdBlocks'):
			from .NfdBlocks import NfdBlocksCls
			self._nfdBlocks = NfdBlocksCls(self._core, self._cmd_group)
		return self._nfdBlocks

	@property
	def nopPoint(self):
		"""nopPoint commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nopPoint'):
			from .NopPoint import NopPointCls
			self._nopPoint = NopPointCls(self._core, self._cmd_group)
		return self._nopPoint

	@property
	def pservice(self):
		"""pservice commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pservice'):
			from .Pservice import PserviceCls
			self._pservice = PserviceCls(self._core, self._cmd_group)
		return self._pservice

	@property
	def rfIndex(self):
		"""rfIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfIndex'):
			from .RfIndex import RfIndexCls
			self._rfIndex = RfIndexCls(self._core, self._cmd_group)
		return self._rfIndex

	@property
	def rletter(self):
		"""rletter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rletter'):
			from .Rletter import RletterCls
			self._rletter = RletterCls(self._core, self._cmd_group)
		return self._rletter

	@property
	def rnumber(self):
		"""rnumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rnumber'):
			from .Rnumber import RnumberCls
			self._rnumber = RnumberCls(self._core, self._cmd_group)
		return self._rnumber

	@property
	def rpdf(self):
		"""rpdf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpdf'):
			from .Rpdf import RpdfCls
			self._rpdf = RpdfCls(self._core, self._cmd_group)
		return self._rpdf

	@property
	def rpdt(self):
		"""rpdt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpdt'):
			from .Rpdt import RpdtCls
			self._rpdt = RpdtCls(self._core, self._cmd_group)
		return self._rpdt

	@property
	def rpif(self):
		"""rpif commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpif'):
			from .Rpif import RpifCls
			self._rpif = RpifCls(self._core, self._cmd_group)
		return self._rpif

	@property
	def rpit(self):
		"""rpit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpit'):
			from .Rpit import RpitCls
			self._rpit = RpitCls(self._core, self._cmd_group)
		return self._rpit

	@property
	def rsdSelector(self):
		"""rsdSelector commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsdSelector'):
			from .RsdSelector import RsdSelectorCls
			self._rsdSelector = RsdSelectorCls(self._core, self._cmd_group)
		return self._rsdSelector

	@property
	def ruIndicator(self):
		"""ruIndicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ruIndicator'):
			from .RuIndicator import RuIndicatorCls
			self._ruIndicator = RuIndicatorCls(self._core, self._cmd_group)
		return self._ruIndicator

	@property
	def runcertainty(self):
		"""runcertainty commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_runcertainty'):
			from .Runcertainty import RuncertaintyCls
			self._runcertainty = RuncertaintyCls(self._core, self._cmd_group)
		return self._runcertainty

	@property
	def sgDefinition(self):
		"""sgDefinition commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_sgDefinition'):
			from .SgDefinition import SgDefinitionCls
			self._sgDefinition = SgDefinitionCls(self._core, self._cmd_group)
		return self._sgDefinition

	@property
	def sheight(self):
		"""sheight commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sheight'):
			from .Sheight import SheightCls
			self._sheight = SheightCls(self._core, self._cmd_group)
		return self._sheight

	@property
	def svid(self):
		"""svid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_svid'):
			from .Svid import SvidCls
			self._svid = SvidCls(self._core, self._cmd_group)
		return self._svid

	@property
	def sviGradient(self):
		"""sviGradient commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sviGradient'):
			from .SviGradient import SviGradientCls
			self._sviGradient = SviGradientCls(self._core, self._cmd_group)
		return self._sviGradient

	@property
	def tdsState(self):
		"""tdsState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdsState'):
			from .TdsState import TdsStateCls
			self._tdsState = TdsStateCls(self._core, self._cmd_group)
		return self._tdsState

	@property
	def tlas(self):
		"""tlas commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tlas'):
			from .Tlas import TlasCls
			self._tlas = TlasCls(self._core, self._cmd_group)
		return self._tlas

	@property
	def tvas(self):
		"""tvas commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tvas'):
			from .Tvas import TvasCls
			self._tvas = TvasCls(self._core, self._cmd_group)
		return self._tvas

	@property
	def waypoint(self):
		"""waypoint commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_waypoint'):
			from .Waypoint import WaypointCls
			self._waypoint = WaypointCls(self._core, self._cmd_group)
		return self._waypoint

	def clone(self) -> 'MconfigCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MconfigCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZadCls:
	"""Zad commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("zad", core, parent)

	@property
	def cycShift(self):
		"""cycShift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cycShift'):
			from .CycShift import CycShiftCls
			self._cycShift = CycShiftCls(self._core, self._cmd_group)
		return self._cycShift

	@property
	def slen(self):
		"""slen commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slen'):
			from .Slen import SlenCls
			self._slen = SlenCls(self._core, self._cmd_group)
		return self._slen

	@property
	def snumber(self):
		"""snumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_snumber'):
			from .Snumber import SnumberCls
			self._snumber = SnumberCls(self._core, self._cmd_group)
		return self._snumber

	def clone(self) -> 'ZadCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ZadCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SettingCls:
	"""Setting commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setting", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLNN:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.wlnn.setting.get_catalog() \n
		Reads out the files with IEEE 802.11a/b/g/n/ac settings in the default directory. The default directory is set using
		command method RsSmbv.MassMemory.currentDirectory. Only files with the file extension *.wlann will be listed. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:SETTing:DELete \n
		Snippet: driver.source.bb.wlnn.setting.delete(filename = 'abc') \n
		Deletes the selected file with IIEEE 802.11a/b/g/n/ac settings. The directory is set using command method RsSmbv.
		MassMemory.currentDirectory. A path can also be specified, in which case the files in the specified directory are read.
		The file extension may be omitted. Only files with the file extension *.wlann are listed and can be deleted. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:SETTing:LOAD \n
		Snippet: driver.source.bb.wlnn.setting.load(filename = 'abc') \n
		Loads the selected file with IEEE 802.11 WLAN settings. The directory is set using command method RsSmbv.MassMemory.
		currentDirectory. A path can also be specified, in which case the files in the specified directory are read. The file
		extension may be omitted. Only files with the file extension *.wlann will be loaded. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:SETTing:STORe \n
		Snippet: driver.source.bb.wlnn.setting.set_store(filename = 'abc') \n
		Saves the current IEEE 802.11a/b/g/n/ac settings into the selected file. The directory is set using command method RsSmbv.
		MassMemory.currentDirectory. A path can also be specified, in which case the files in the specified directory are read.
		Only the file name has to be entered. IEEE 802.11a/b/g/n/ac/ax settings are saved as files with file extension *.wlann. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:SETTing:STORe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CiValueCls:
	"""CiValue commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ciValue", core, parent)

	def set(self, ci_value: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.ciValue.set(ci_value = rawAbc, bitcount = 1) \n
		Sets the initialization value for the CRC (Cyclic Redundancy Check, 24 bits) calculation. A packet has been received
		correctly, when it has passed the CRC check. \n
			:param ci_value: numeric
			:param bitcount: integer Range: 24 to 24
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('ci_value', ci_value, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue {param}'.rstrip())

	# noinspection PyTypeChecker
	class CiValueStruct(StructBase):
		"""Response structure. Fields: \n
			- Ci_Value: str: numeric
			- Bitcount: int: integer Range: 24 to 24"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Ci_Value'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Ci_Value: str = None
			self.Bitcount: int = None

	def get(self) -> CiValueStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue \n
		Snippet: value: CiValueStruct = driver.source.bb.btooth.econfiguration.pconfiguration.ciValue.get() \n
		Sets the initialization value for the CRC (Cyclic Redundancy Check, 24 bits) calculation. A packet has been received
		correctly, when it has passed the CRC check. \n
			:return: structure: for return value, see the help for CiValueStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:CIValue?', self.__class__.CiValueStruct())



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class U2TpcCls:
	"""U2Tpc commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("u2Tpc", core, parent)

	def set(self, use_second_tpc: bool, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:PUCCh:U2TPc \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.pucch.u2Tpc.set(use_second_tpc = False, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Turns the '2nd TPC Command for Scheduled PUCCH' DCI field on and off. \n
			:param use_second_tpc: 1| ON| 0| OFF
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.bool_to_str(use_second_tpc)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:PUCCh:U2TPc {param}')

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:PUCCh:U2TPc \n
		Snippet: value: bool = driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.pucch.u2Tpc.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Turns the '2nd TPC Command for Scheduled PUCCH' DCI field on and off. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: use_second_tpc: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:PUCCh:U2TPc?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PoffsetCls:
	"""Poffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("poffset", core, parent)

	def set(self, sm_phas_offset: float, stream=repcap.Stream.Default) -> None:
		"""SCPI: SCONfiguration:OUTPut:MAPPing:STReam<ST>:POFFset \n
		Snippet: driver.sconfiguration.output.mapping.stream.poffset.set(sm_phas_offset = 1.0, stream = repcap.Stream.Default) \n
		Sets the phase offset of the corresponding stream. \n
			:param sm_phas_offset: float Range: -999.99 to 999.99
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
		"""
		param = Conversions.decimal_value_to_str(sm_phas_offset)
		stream_cmd_val = self._cmd_group.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SCONfiguration:OUTPut:MAPPing:STReam{stream_cmd_val}:POFFset {param}')

	def get(self, stream=repcap.Stream.Default) -> float:
		"""SCPI: SCONfiguration:OUTPut:MAPPing:STReam<ST>:POFFset \n
		Snippet: value: float = driver.sconfiguration.output.mapping.stream.poffset.get(stream = repcap.Stream.Default) \n
		Sets the phase offset of the corresponding stream. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:return: sm_phas_offset: float Range: -999.99 to 999.99"""
		stream_cmd_val = self._cmd_group.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SCONfiguration:OUTPut:MAPPing:STReam{stream_cmd_val}:POFFset?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def get(self, cell=repcap.Cell.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:UPPTs:STATe \n
		Snippet: value: bool = driver.source.bb.tdscdma.up.cell.uppts.state.get(cell = repcap.Cell.Default) \n
		Queries the state of the downlink/uplink pilot timeslot. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: state: 1| ON| 0| OFF"""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:UPPTs:STATe?')
		return Conversions.str_to_bool(response)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsCls:
	"""Cs commands group definition. 295 total commands, 14 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cs", core, parent)

	@property
	def aulBwp(self):
		"""aulBwp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aulBwp'):
			from .AulBwp import AulBwpCls
			self._aulBwp = AulBwpCls(self._core, self._cmd_group)
		return self._aulBwp

	@property
	def dcces(self):
		"""dcces commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dcces'):
			from .Dcces import DccesCls
			self._dcces = DccesCls(self._core, self._cmd_group)
		return self._dcces

	@property
	def dci(self):
		"""dci commands group. 268 Sub-classes, 0 commands."""
		if not hasattr(self, '_dci'):
			from .Dci import DciCls
			self._dci = DciCls(self._core, self._cmd_group)
		return self._dci

	@property
	def dmrs(self):
		"""dmrs commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmrs'):
			from .Dmrs import DmrsCls
			self._dmrs = DmrsCls(self._core, self._cmd_group)
		return self._dmrs

	@property
	def id(self):
		"""id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_id'):
			from .Id import IdCls
			self._id = IdCls(self._core, self._cmd_group)
		return self._id

	@property
	def il(self):
		"""il commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_il'):
			from .Il import IlCls
			self._il = IlCls(self._core, self._cmd_group)
		return self._il

	@property
	def ndci(self):
		"""ndci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndci'):
			from .Ndci import NdciCls
			self._ndci = NdciCls(self._core, self._cmd_group)
		return self._ndci

	@property
	def nsci(self):
		"""nsci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsci'):
			from .Nsci import NsciCls
			self._nsci = NsciCls(self._core, self._cmd_group)
		return self._nsci

	@property
	def preGran(self):
		"""preGran commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_preGran'):
			from .PreGran import PreGranCls
			self._preGran = PreGranCls(self._core, self._cmd_group)
		return self._preGran

	@property
	def puncturing(self):
		"""puncturing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_puncturing'):
			from .Puncturing import PuncturingCls
			self._puncturing = PuncturingCls(self._core, self._cmd_group)
		return self._puncturing

	@property
	def refDmrs(self):
		"""refDmrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refDmrs'):
			from .RefDmrs import RefDmrsCls
			self._refDmrs = RefDmrsCls(self._core, self._cmd_group)
		return self._refDmrs

	@property
	def resAlloc(self):
		"""resAlloc commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_resAlloc'):
			from .ResAlloc import ResAllocCls
			self._resAlloc = ResAllocCls(self._core, self._cmd_group)
		return self._resAlloc

	@property
	def tci(self):
		"""tci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tci'):
			from .Tci import TciCls
			self._tci = TciCls(self._core, self._cmd_group)
		return self._tci

	@property
	def ts12(self):
		"""ts12 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ts12'):
			from .Ts12 import Ts12Cls
			self._ts12 = Ts12Cls(self._core, self._cmd_group)
		return self._ts12

	def clone(self) -> 'CsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CellCls:
	"""Cell commands group definition. 130 total commands, 24 Subgroups, 0 group commands
	Repeated Capability: CellNull, default value after init: CellNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cell", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_cellNull_get', 'repcap_cellNull_set', repcap.CellNull.Nr0)

	def repcap_cellNull_set(self, cellNull: repcap.CellNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CellNull.Default
		Default value after init: CellNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(cellNull)

	def repcap_cellNull_get(self) -> repcap.CellNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def cardeply(self):
		"""cardeply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cardeply'):
			from .Cardeply import CardeplyCls
			self._cardeply = CardeplyCls(self._core, self._cmd_group)
		return self._cardeply

	@property
	def cbw(self):
		"""cbw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbw'):
			from .Cbw import CbwCls
			self._cbw = CbwCls(self._core, self._cmd_group)
		return self._cbw

	@property
	def cellId(self):
		"""cellId commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cellId'):
			from .CellId import CellIdCls
			self._cellId = CellIdCls(self._core, self._cmd_group)
		return self._cellId

	@property
	def cif(self):
		"""cif commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cif'):
			from .Cif import CifCls
			self._cif = CifCls(self._core, self._cmd_group)
		return self._cif

	@property
	def cifPresent(self):
		"""cifPresent commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cifPresent'):
			from .CifPresent import CifPresentCls
			self._cifPresent = CifPresentCls(self._core, self._cmd_group)
		return self._cifPresent

	@property
	def dfreq(self):
		"""dfreq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfreq'):
			from .Dfreq import DfreqCls
			self._dfreq = DfreqCls(self._core, self._cmd_group)
		return self._dfreq

	@property
	def dumRes(self):
		"""dumRes commands group. 12 Sub-classes, 0 commands."""
		if not hasattr(self, '_dumRes'):
			from .DumRes import DumResCls
			self._dumRes = DumResCls(self._core, self._cmd_group)
		return self._dumRes

	@property
	def lte(self):
		"""lte commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_lte'):
			from .Lte import LteCls
			self._lte = LteCls(self._core, self._cmd_group)
		return self._lte

	@property
	def mapped(self):
		"""mapped commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mapped'):
			from .Mapped import MappedCls
			self._mapped = MappedCls(self._core, self._cmd_group)
		return self._mapped

	@property
	def n1Id(self):
		"""n1Id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n1Id'):
			from .N1Id import N1IdCls
			self._n1Id = N1IdCls(self._core, self._cmd_group)
		return self._n1Id

	@property
	def n2Id(self):
		"""n2Id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n2Id'):
			from .N2Id import N2IdCls
			self._n2Id = N2IdCls(self._core, self._cmd_group)
		return self._n2Id

	@property
	def nsspbch(self):
		"""nsspbch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsspbch'):
			from .Nsspbch import NsspbchCls
			self._nsspbch = NsspbchCls(self._core, self._cmd_group)
		return self._nsspbch

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def pcFreq(self):
		"""pcFreq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcFreq'):
			from .PcFreq import PcFreqCls
			self._pcFreq = PcFreqCls(self._core, self._cmd_group)
		return self._pcFreq

	@property
	def prs(self):
		"""prs commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_prs'):
			from .Prs import PrsCls
			self._prs = PrsCls(self._core, self._cmd_group)
		return self._prs

	@property
	def rfPhase(self):
		"""rfPhase commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfPhase'):
			from .RfPhase import RfPhaseCls
			self._rfPhase = RfPhaseCls(self._core, self._cmd_group)
		return self._rfPhase

	@property
	def rpow(self):
		"""rpow commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpow'):
			from .Rpow import RpowCls
			self._rpow = RpowCls(self._core, self._cmd_group)
		return self._rpow

	@property
	def schby(self):
		"""schby commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_schby'):
			from .Schby import SchbyCls
			self._schby = SchbyCls(self._core, self._cmd_group)
		return self._schby

	@property
	def shSpec(self):
		"""shSpec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_shSpec'):
			from .ShSpec import ShSpecCls
			self._shSpec = ShSpecCls(self._core, self._cmd_group)
		return self._shSpec

	@property
	def sspbch(self):
		"""sspbch commands group. 16 Sub-classes, 0 commands."""
		if not hasattr(self, '_sspbch'):
			from .Sspbch import SspbchCls
			self._sspbch = SspbchCls(self._core, self._cmd_group)
		return self._sspbch

	@property
	def syInfo(self):
		"""syInfo commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_syInfo'):
			from .SyInfo import SyInfoCls
			self._syInfo = SyInfoCls(self._core, self._cmd_group)
		return self._syInfo

	@property
	def tapos(self):
		"""tapos commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tapos'):
			from .Tapos import TaposCls
			self._tapos = TaposCls(self._core, self._cmd_group)
		return self._tapos

	@property
	def tmph(self):
		"""tmph commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_tmph'):
			from .Tmph import TmphCls
			self._tmph = TmphCls(self._core, self._cmd_group)
		return self._tmph

	@property
	def txbw(self):
		"""txbw commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_txbw'):
			from .Txbw import TxbwCls
			self._txbw = TxbwCls(self._core, self._cmd_group)
		return self._txbw

	def clone(self) -> 'CellCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CellCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PscchCls:
	"""Pscch commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pscch", core, parent)

	@property
	def bdWidth(self):
		"""bdWidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdWidth'):
			from .BdWidth import BdWidthCls
			self._bdWidth = BdWidthCls(self._core, self._cmd_group)
		return self._bdWidth

	@property
	def scrid(self):
		"""scrid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scrid'):
			from .Scrid import ScridCls
			self._scrid = ScridCls(self._core, self._cmd_group)
		return self._scrid

	@property
	def symLength(self):
		"""symLength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symLength'):
			from .SymLength import SymLengthCls
			self._symLength = SymLengthCls(self._core, self._cmd_group)
		return self._symLength

	def clone(self) -> 'PscchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PscchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DtTestCls:
	"""DtTest commands group definition. 18 total commands, 3 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dtTest", core, parent)

	@property
	def stDefault(self):
		"""stDefault commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stDefault'):
			from .StDefault import StDefaultCls
			self._stDefault = StDefaultCls(self._core, self._cmd_group)
		return self._stDefault

	@property
	def table(self):
		"""table commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_table'):
			from .Table import TableCls
			self._table = TableCls(self._core, self._cmd_group)
		return self._table

	@property
	def tpConfiguration(self):
		"""tpConfiguration commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_tpConfiguration'):
			from .TpConfiguration import TpConfigurationCls
			self._tpConfiguration = TpConfigurationCls(self._core, self._cmd_group)
		return self._tpConfiguration

	def get_drift(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:DIRft \n
		Snippet: value: bool = driver.source.bb.btooth.dtTest.get_drift() \n
		No command help available \n
			:return: drift: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:DIRft?')
		return Conversions.str_to_bool(response)

	def set_drift(self, drift: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:DIRft \n
		Snippet: driver.source.bb.btooth.dtTest.set_drift(drift = False) \n
		No command help available \n
			:param drift: No help available
		"""
		param = Conversions.bool_to_str(drift)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:DIRft {param}')

	def get_dtt_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:DTTState \n
		Snippet: value: bool = driver.source.bb.btooth.dtTest.get_dtt_state() \n
		Activates the 'Dirty Transmitter Test'. For EDR packets, the parameter sets apply for 20 packets each. \n
			:return: dtt_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:DTTState?')
		return Conversions.str_to_bool(response)

	def set_dtt_state(self, dtt_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:DTTState \n
		Snippet: driver.source.bb.btooth.dtTest.set_dtt_state(dtt_state = False) \n
		Activates the 'Dirty Transmitter Test'. For EDR packets, the parameter sets apply for 20 packets each. \n
			:param dtt_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(dtt_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:DTTState {param}')

	def get_fd_deviation(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:FDDeviation \n
		Snippet: value: int = driver.source.bb.btooth.dtTest.get_fd_deviation() \n
		Sets a frequency drift rate. A sine wave is used to drift the modulated Bluetooth signal around center frequency +
		carrier frequency offset. The maximum deviation reached during the drift equals the set frequency drift deviation. \n
			:return: fd_deviation: integer Range: -100 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:FDDeviation?')
		return Conversions.str_to_int(response)

	def set_fd_deviation(self, fd_deviation: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:FDDeviation \n
		Snippet: driver.source.bb.btooth.dtTest.set_fd_deviation(fd_deviation = 1) \n
		Sets a frequency drift rate. A sine wave is used to drift the modulated Bluetooth signal around center frequency +
		carrier frequency offset. The maximum deviation reached during the drift equals the set frequency drift deviation. \n
			:param fd_deviation: integer Range: -100 to 100
		"""
		param = Conversions.decimal_value_to_str(fd_deviation)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:FDDeviation {param}')

	def get_fd_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:FDRate \n
		Snippet: value: float = driver.source.bb.btooth.dtTest.get_fd_rate() \n
		Sets a frequency drift rate. A sine wave is used to drift the modulated Bluetooth signal around center frequency +
		carrier frequency offset with the set frequency drift rate. \n
			:return: fd_rate: 0.3 KHz| 0.5 KHz| 1.6 KHz| 10 KHz Range: depends on packet type to depends on packet type
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:FDRate?')
		return Conversions.str_to_float(response)

	def set_fd_rate(self, fd_rate: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:FDRate \n
		Snippet: driver.source.bb.btooth.dtTest.set_fd_rate(fd_rate = 1.0) \n
		Sets a frequency drift rate. A sine wave is used to drift the modulated Bluetooth signal around center frequency +
		carrier frequency offset with the set frequency drift rate. \n
			:param fd_rate: 0.3 KHz| 0.5 KHz| 1.6 KHz| 10 KHz Range: depends on packet type to depends on packet type
		"""
		param = Conversions.decimal_value_to_str(fd_rate)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:FDRate {param}')

	# noinspection PyTypeChecker
	def get_mi_mode(self) -> enums.BtoModIdxMode:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:MIMode \n
		Snippet: value: enums.BtoModIdxMode = driver.source.bb.btooth.dtTest.get_mi_mode() \n
		Determines standard or stable mode for the modulation index of dirty transmitter according to the Bluetooth core
		specification. \n
			:return: mi_mode: STANdard| STABle
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:MIMode?')
		return Conversions.str_to_scalar_enum(response, enums.BtoModIdxMode)

	def set_mi_mode(self, mi_mode: enums.BtoModIdxMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:MIMode \n
		Snippet: driver.source.bb.btooth.dtTest.set_mi_mode(mi_mode = enums.BtoModIdxMode.STABle) \n
		Determines standard or stable mode for the modulation index of dirty transmitter according to the Bluetooth core
		specification. \n
			:param mi_mode: STANdard| STABle
		"""
		param = Conversions.enum_scalar_to_str(mi_mode, enums.BtoModIdxMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:MIMode {param}')

	# noinspection PyTypeChecker
	def get_nppset(self) -> enums.BtoNumOfPackPerSet:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:NPPSet \n
		Snippet: value: enums.BtoNumOfPackPerSet = driver.source.bb.btooth.dtTest.get_nppset() \n
		Specifies the number of packets per dirty transmitter set.
			Table Header: Bluetooth mode / Channel type / Number of packets \n
			- BR + EDR / 50, 2, 1 packets
			- LE / Advertising, data / 50, 2, 1 packets \n
			:return: num_pack: NP50| NP2| NP1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:NPPSet?')
		return Conversions.str_to_scalar_enum(response, enums.BtoNumOfPackPerSet)

	def set_nppset(self, num_pack: enums.BtoNumOfPackPerSet) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:NPPSet \n
		Snippet: driver.source.bb.btooth.dtTest.set_nppset(num_pack = enums.BtoNumOfPackPerSet.NP1) \n
		Specifies the number of packets per dirty transmitter set.
			Table Header: Bluetooth mode / Channel type / Number of packets \n
			- BR + EDR / 50, 2, 1 packets
			- LE / Advertising, data / 50, 2, 1 packets \n
			:param num_pack: NP50| NP2| NP1
		"""
		param = Conversions.enum_scalar_to_str(num_pack, enums.BtoNumOfPackPerSet)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:NPPSet {param}')

	def get_sphase(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:SPHase \n
		Snippet: value: int = driver.source.bb.btooth.dtTest.get_sphase() \n
		The command enters a start phase. The start phase applies to the sine wave that is used to drift the modulated Bluetooth
		signal. The drift is around the center frequency plus the carrier frequency offset. \n
			:return: sphase: integer Range: 0 to 359, Unit: degree
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DTTest:SPHase?')
		return Conversions.str_to_int(response)

	def set_sphase(self, sphase: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:SPHase \n
		Snippet: driver.source.bb.btooth.dtTest.set_sphase(sphase = 1) \n
		The command enters a start phase. The start phase applies to the sine wave that is used to drift the modulated Bluetooth
		signal. The drift is around the center frequency plus the carrier frequency offset. \n
			:param sphase: integer Range: 0 to 359, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(sphase)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:SPHase {param}')

	def clone(self) -> 'DtTestCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DtTestCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PredefinedCls:
	"""Predefined commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("predefined", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	def load(self, filename: str, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:PREDefined:LOAD \n
		Snippet: driver.source.bb.gsm.frame.slot.subChannel.user.predefined.load(filename = 'abc', frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		This command loads the selected file with predefined slot settings. The directory is pre-set, therefore a path cannot be
		specified. \n
			:param filename: string
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.value_to_quoted_str(filename)
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:PREDefined:LOAD {param}')

	def clone(self) -> 'PredefinedCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PredefinedCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.RoscOutpFreqMode:
		"""SCPI: [SOURce]:ROSCillator:OUTPut:FREQuency:MODE \n
		Snippet: value: enums.RoscOutpFreqMode = driver.source.roscillator.output.frequency.get_mode() \n
		Selects the mode for the output reference frequency. \n
			:return: outp_freq_mode: DER10M| OFF| LOOPthrough OFF Disables the output. DER10M Sets the output reference frequency to 10 MHz. The reference frequency is derived from the internal reference frequency. LOOPthrough This setting is unavailable for ROSCillator:EXTernal:FREQuency 1GHZ. Forwards the input reference frequency to the reference frequency output.
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:OUTPut:FREQuency:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.RoscOutpFreqMode)

	def set_mode(self, outp_freq_mode: enums.RoscOutpFreqMode) -> None:
		"""SCPI: [SOURce]:ROSCillator:OUTPut:FREQuency:MODE \n
		Snippet: driver.source.roscillator.output.frequency.set_mode(outp_freq_mode = enums.RoscOutpFreqMode.DER10M) \n
		Selects the mode for the output reference frequency. \n
			:param outp_freq_mode: DER10M| OFF| LOOPthrough OFF Disables the output. DER10M Sets the output reference frequency to 10 MHz. The reference frequency is derived from the internal reference frequency. LOOPthrough This setting is unavailable for ROSCillator:EXTernal:FREQuency 1GHZ. Forwards the input reference frequency to the reference frequency output.
		"""
		param = Conversions.enum_scalar_to_str(outp_freq_mode, enums.RoscOutpFreqMode)
		self._core.io.write(f'SOURce:ROSCillator:OUTPut:FREQuency:MODE {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	def set(self, carrier_index: int, phase: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:MCCW:CARRier:PHASe \n
		Snippet: driver.source.bb.mccw.carrier.phase.set(carrier_index = 1, phase = 1.0) \n
		For disabled optimization of the crest factor, sets the start phase of the selected carrier. \n
			:param carrier_index: integer Range: 0 to lastCarrier
			:param phase: float Range: 0 to 359.99, Unit: DEG
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('carrier_index', carrier_index, DataType.Integer), ArgSingle('phase', phase, DataType.Float))
		self._core.io.write(f'SOURce<HwInstance>:BB:MCCW:CARRier:PHASe {param}'.rstrip())

	# noinspection PyTypeChecker
	class PhaseStruct(StructBase):
		"""Response structure. Fields: \n
			- Carrier_Index: int: integer Range: 0 to lastCarrier
			- Phase: float: float Range: 0 to 359.99, Unit: DEG"""
		__meta_args_list = [
			ArgStruct.scalar_int('Carrier_Index'),
			ArgStruct.scalar_float('Phase')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Carrier_Index: int = None
			self.Phase: float = None

	def get(self) -> PhaseStruct:
		"""SCPI: [SOURce<HW>]:BB:MCCW:CARRier:PHASe \n
		Snippet: value: PhaseStruct = driver.source.bb.mccw.carrier.phase.get() \n
		For disabled optimization of the crest factor, sets the start phase of the selected carrier. \n
			:return: structure: for return value, see the help for PhaseStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:MCCW:CARRier:PHASe?', self.__class__.PhaseStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoDeviceCls:
	"""CoDevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coDevice", core, parent)

	def set(self, co_device: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:CODevice \n
		Snippet: driver.source.bb.btooth.pconfiguration.coDevice.set(co_device = rawAbc, bitcount = 1) \n
		A parameter received during the device discovery procedure, indicates the type of device and which types of service that
		are supported. \n
			:param co_device: numeric Range: #H000000 to #HFFFFFF
			:param bitcount: integer Range: 24 to 24
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('co_device', co_device, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:CODevice {param}'.rstrip())

	# noinspection PyTypeChecker
	class CoDeviceStruct(StructBase):
		"""Response structure. Fields: \n
			- Co_Device: str: numeric Range: #H000000 to #HFFFFFF
			- Bitcount: int: integer Range: 24 to 24"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Co_Device'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Co_Device: str = None
			self.Bitcount: int = None

	def get(self) -> CoDeviceStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:CODevice \n
		Snippet: value: CoDeviceStruct = driver.source.bb.btooth.pconfiguration.coDevice.get() \n
		A parameter received during the device discovery procedure, indicates the type of device and which types of service that
		are supported. \n
			:return: structure: for return value, see the help for CoDeviceStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:CODevice?', self.__class__.CoDeviceStruct())



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.PowContMode, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:MODE \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.mode.set(mode = enums.PowContMode.EXTernal, channelNull = repcap.ChannelNull.Default) \n
		Selects the control signal source for Dynamic Power Control. \n
			:param mode: TPC| MANual
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PowContMode)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, channelNull=repcap.ChannelNull.Default) -> enums.PowContMode:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:MODE \n
		Snippet: value: enums.PowContMode = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.mode.get(channelNull = repcap.ChannelNull.Default) \n
		Selects the control signal source for Dynamic Power Control. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: mode: TPC| MANual"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PowContMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OntimeCls:
	"""Ontime commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ontime", core, parent)

	def get_points(self) -> int:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:ONTime:POINts \n
		Snippet: value: int = driver.source.pulm.train.hopping.ontime.get_points() \n
		No command help available \n
			:return: points: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:HOPPing:ONTime:POINts?')
		return Conversions.str_to_int(response)

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:ONTime \n
		Snippet: value: str = driver.source.pulm.train.hopping.ontime.get_value() \n
		No command help available \n
			:return: ontime: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRAin:HOPPing:ONTime?')
		return trim_str_response(response)

	def set_value(self, ontime: str) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRAin:HOPPing:ONTime \n
		Snippet: driver.source.pulm.train.hopping.ontime.set_value(ontime = 'abc') \n
		No command help available \n
			:param ontime: No help available
		"""
		param = Conversions.value_to_quoted_str(ontime)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRAin:HOPPing:ONTime {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValRfCls:
	"""ValRf commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("valRf", core, parent)

	# noinspection PyTypeChecker
	def get_slope(self) -> enums.SlopeType:
		"""SCPI: [SOURce<HW>]:VALRf:SLOPe \n
		Snippet: value: enums.SlopeType = driver.source.valRf.get_slope() \n
		No command help available \n
			:return: sig_valid_slope: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:VALRf:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SlopeType)

	def set_slope(self, sig_valid_slope: enums.SlopeType) -> None:
		"""SCPI: [SOURce<HW>]:VALRf:SLOPe \n
		Snippet: driver.source.valRf.set_slope(sig_valid_slope = enums.SlopeType.NEGative) \n
		No command help available \n
			:param sig_valid_slope: No help available
		"""
		param = Conversions.enum_scalar_to_str(sig_valid_slope, enums.SlopeType)
		self._core.io.write(f'SOURce<HwInstance>:VALRf:SLOPe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReShiftCls:
	"""ReShift commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("reShift", core, parent)

	def set(self, shift: float, output=repcap.Output.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:TRIGger:OUTPut<CH>:RESHift \n
		Snippet: driver.source.bb.btooth.trigger.output.reShift.set(shift = 1.0, output = repcap.Output.Default) \n
		Shifts the rising edge of the marker the specified number of samples. Negative values result in a shift back of the
		marker edge. \n
			:param shift: float Range: dynamic to dynamic
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.decimal_value_to_str(shift)
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:TRIGger:OUTPut{output_cmd_val}:RESHift {param}')

	def get(self, output=repcap.Output.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:TRIGger:OUTPut<CH>:RESHift \n
		Snippet: value: float = driver.source.bb.btooth.trigger.output.reShift.get(output = repcap.Output.Default) \n
		Shifts the rising edge of the marker the specified number of samples. Negative values result in a shift back of the
		marker edge. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: shift: float Range: dynamic to dynamic"""
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:TRIGger:OUTPut{output_cmd_val}:RESHift?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RntiCls:
	"""Rnti commands group definition. 7 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rnti", core, parent)

	@property
	def aiRnti(self):
		"""aiRnti commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aiRnti'):
			from .AiRnti import AiRntiCls
			self._aiRnti = AiRntiCls(self._core, self._cmd_group)
		return self._aiRnti

	@property
	def ciRnti(self):
		"""ciRnti commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ciRnti'):
			from .CiRnti import CiRntiCls
			self._ciRnti = CiRntiCls(self._core, self._cmd_group)
		return self._ciRnti

	@property
	def int(self):
		"""int commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_int'):
			from .Int import IntCls
			self._int = IntCls(self._core, self._cmd_group)
		return self._int

	@property
	def psRnti(self):
		"""psRnti commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psRnti'):
			from .PsRnti import PsRntiCls
			self._psRnti = PsRntiCls(self._core, self._cmd_group)
		return self._psRnti

	@property
	def pucch(self):
		"""pucch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pucch'):
			from .Pucch import PucchCls
			self._pucch = PucchCls(self._core, self._cmd_group)
		return self._pucch

	@property
	def pusch(self):
		"""pusch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pusch'):
			from .Pusch import PuschCls
			self._pusch = PuschCls(self._core, self._cmd_group)
		return self._pusch

	@property
	def srs(self):
		"""srs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srs'):
			from .Srs import SrsCls
			self._srs = SrsCls(self._core, self._cmd_group)
		return self._srs

	def clone(self) -> 'RntiCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RntiCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RemoveCls:
	"""Remove commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("remove", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	def clone(self) -> 'RemoveCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RemoveCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GcidCls:
	"""Gcid commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gcid", core, parent)

	def set(self, gcid: enums.GbasGcid, vdbTransmitter=repcap.VdbTransmitter.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:MCONfig:GCID \n
		Snippet: driver.source.bb.gbas.vdb.mconfig.gcid.set(gcid = enums.GbasGcid.FC, vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Sets the ground station continuity/integrity designator. \n
			:param gcid: FC| FD
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
		"""
		param = Conversions.enum_scalar_to_str(gcid, enums.GbasGcid)
		vdbTransmitter_cmd_val = self._cmd_group.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:MCONfig:GCID {param}')

	# noinspection PyTypeChecker
	def get(self, vdbTransmitter=repcap.VdbTransmitter.Default) -> enums.GbasGcid:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:MCONfig:GCID \n
		Snippet: value: enums.GbasGcid = driver.source.bb.gbas.vdb.mconfig.gcid.get(vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Sets the ground station continuity/integrity designator. \n
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:return: gcid: FC| FD"""
		vdbTransmitter_cmd_val = self._cmd_group.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:MCONfig:GCID?')
		return Conversions.str_to_scalar_enum(response, enums.GbasGcid)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdentificationCls:
	"""Identification commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("identification", core, parent)

	def get_catalog(self) -> str:
		"""SCPI: SYSTem:SPECification:IDENtification:CATalog \n
		Snippet: value: str = driver.system.specification.identification.get_catalog() \n
		Queries the parameter identifiers (<Id>) available in the data sheet. \n
			:return: id_list: string Comma-separated string of the parameter identifiers (Id)
		"""
		response = self._core.io.query_str('SYSTem:SPECification:IDENtification:CATalog?')
		return trim_str_response(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal.Types import DataType
from ...........Internal.StructBase import StructBase
from ...........Internal.ArgStruct import ArgStruct
from ...........Internal.ArgSingleList import ArgSingleList
from ...........Internal.ArgSingle import ArgSingle
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternCls:
	"""Pattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pattern", core, parent)

	def set(self, emtc_ack_nack_pat: str, bitcount: int, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:EMTC:TRANs<CH>:PUCCh:HARQ:PATTern \n
		Snippet: driver.source.bb.eutra.uplink.ue.emtc.trans.pucch.harq.pattern.set(emtc_ack_nack_pat = rawAbc, bitcount = 1, userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		Sets the PUCCH ACK/NACK pattern. \n
			:param emtc_ack_nack_pat: numeric
			:param bitcount: integer Range: 1 to 64
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('emtc_ack_nack_pat', emtc_ack_nack_pat, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._cmd_group.get_repcap_cmd_value(transmission, repcap.Transmission)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:EMTC:TRANs{transmission_cmd_val}:PUCCh:HARQ:PATTern {param}'.rstrip())

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Response structure. Fields: \n
			- Emtc_Ack_Nack_Pat: str: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Emtc_Ack_Nack_Pat'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Emtc_Ack_Nack_Pat: str = None
			self.Bitcount: int = None

	def get(self, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:EMTC:TRANs<CH>:PUCCh:HARQ:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.eutra.uplink.ue.emtc.trans.pucch.harq.pattern.get(userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		Sets the PUCCH ACK/NACK pattern. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')
			:return: structure: for return value, see the help for PatternStruct structure arguments."""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._cmd_group.get_repcap_cmd_value(transmission, repcap.Transmission)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:EMTC:TRANs{transmission_cmd_val}:PUCCh:HARQ:PATTern?', self.__class__.PatternStruct())



from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TpCls:
	"""Tp commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tp", core, parent)

	@property
	def rb0(self):
		"""rb0 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb0'):
			from .Rb0 import Rb0Cls
			self._rb0 = Rb0Cls(self._core, self._cmd_group)
		return self._rb0

	@property
	def rb1(self):
		"""rb1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb1'):
			from .Rb1 import Rb1Cls
			self._rb1 = Rb1Cls(self._core, self._cmd_group)
		return self._rb1

	@property
	def rb2(self):
		"""rb2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb2'):
			from .Rb2 import Rb2Cls
			self._rb2 = Rb2Cls(self._core, self._cmd_group)
		return self._rb2

	@property
	def rb3(self):
		"""rb3 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb3'):
			from .Rb3 import Rb3Cls
			self._rb3 = Rb3Cls(self._core, self._cmd_group)
		return self._rb3

	@property
	def rb4(self):
		"""rb4 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb4'):
			from .Rb4 import Rb4Cls
			self._rb4 = Rb4Cls(self._core, self._cmd_group)
		return self._rb4

	@property
	def scid(self):
		"""scid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scid'):
			from .Scid import ScidCls
			self._scid = ScidCls(self._core, self._cmd_group)
		return self._scid

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def tmDensity(self):
		"""tmDensity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tmDensity'):
			from .TmDensity import TmDensityCls
			self._tmDensity = TmDensityCls(self._core, self._cmd_group)
		return self._tmDensity

	def clone(self) -> 'TpCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TpCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NtmEntryCls:
	"""NtmEntry commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ntmEntry", core, parent)

	def set(self, num_ul_bp_pucch_ack: float, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:PUCCh:PDSHarq:NTMentry \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.pucch.pdsharq.ntmEntry.set(num_ul_bp_pucch_ack = 1.0, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Sets the number of entries in the sequence of PDSCH to HARQ timing values. The value set here defines the available
		suffixes in the command [:SOURce<hw>]:BB:NR5G:UBWP:USER<us>:CELL<cc>:UL:BWP<bwp>:PUCCh:PDSHarq:TMIValue<gr0>. \n
			:param num_ul_bp_pucch_ack: float Range: 0 to 8
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.decimal_value_to_str(num_ul_bp_pucch_ack)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:PUCCh:PDSHarq:NTMentry {param}')

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:PUCCh:PDSHarq:NTMentry \n
		Snippet: value: float = driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.pucch.pdsharq.ntmEntry.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Sets the number of entries in the sequence of PDSCH to HARQ timing values. The value set here defines the available
		suffixes in the command [:SOURce<hw>]:BB:NR5G:UBWP:USER<us>:CELL<cc>:UL:BWP<bwp>:PUCCh:PDSHarq:TMIValue<gr0>. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: num_ul_bp_pucch_ack: float Range: 0 to 8"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:PUCCh:PDSHarq:NTMentry?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IcaoCls:
	"""Icao commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("icao", core, parent)

	# noinspection PyTypeChecker
	def get_channel(self) -> enums.AvionicIlsIcaoChan:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:ICAO:CHANnel \n
		Snippet: value: enums.AvionicIlsIcaoChan = driver.source.bb.ils.gs.icao.get_channel() \n
		Sets the ICAO channel and the corresponding transmitting frequency. If avionic standard modulation is activated and you
		change the 'RF Frequency', the frequency value of the closest ICAO channel is applied automatically. The 'ICAO Channel'
		is also updated. The ICAO channel settings for ILS glide slope/localizer components are coupled. For an overview of the
		ILS ICAO channel frequencies, see Table 'ILS ICAO channels and frequencies (MHz) '. \n
			:return: channel: CH18X| CH18Y| CH20X| CH20Y| CH22X| CH22Y| CH24X| CH24Y| CH26X| CH26Y| CH28X| CH28Y| CH30X| CH30Y| CH32X| CH32Y| CH34X| CH34Y| CH36X| CH36Y| CH38X| CH38Y| CH40X| CH40Y| CH42X| CH42Y| CH44X| CH44Y| CH46X| CH46Y| CH48X| CH48Y| CH50X| CH50Y| CH52X| CH52Y| CH54X| CH54Y| CH56X| CH56Y
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:ICAO:CHANnel?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicIlsIcaoChan)

	def set_channel(self, channel: enums.AvionicIlsIcaoChan) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:ICAO:CHANnel \n
		Snippet: driver.source.bb.ils.gs.icao.set_channel(channel = enums.AvionicIlsIcaoChan.CH18X) \n
		Sets the ICAO channel and the corresponding transmitting frequency. If avionic standard modulation is activated and you
		change the 'RF Frequency', the frequency value of the closest ICAO channel is applied automatically. The 'ICAO Channel'
		is also updated. The ICAO channel settings for ILS glide slope/localizer components are coupled. For an overview of the
		ILS ICAO channel frequencies, see Table 'ILS ICAO channels and frequencies (MHz) '. \n
			:param channel: CH18X| CH18Y| CH20X| CH20Y| CH22X| CH22Y| CH24X| CH24Y| CH26X| CH26Y| CH28X| CH28Y| CH30X| CH30Y| CH32X| CH32Y| CH34X| CH34Y| CH36X| CH36Y| CH38X| CH38Y| CH40X| CH40Y| CH42X| CH42Y| CH44X| CH44Y| CH46X| CH46Y| CH48X| CH48Y| CH50X| CH50Y| CH52X| CH52Y| CH54X| CH54Y| CH56X| CH56Y
		"""
		param = Conversions.enum_scalar_to_str(channel, enums.AvionicIlsIcaoChan)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:ICAO:CHANnel {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DwellCls:
	"""Dwell commands group definition. 4 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dwell", core, parent)

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ParameterSetMode:
		"""SCPI: [SOURce<HW>]:LIST:DWELl:MODE \n
		Snippet: value: enums.ParameterSetMode = driver.source.listPy.dwell.get_mode() \n
		Selects the dwell time mode. \n
			:return: dwell_mode: LIST| GLOBal LIST Uses the dwell time, specified in the data table for each value pair individually. GLOBal Uses a constant dwell time, set with command [:SOURcehw]:LIST:DWELl.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LIST:DWELl:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ParameterSetMode)

	def set_mode(self, dwell_mode: enums.ParameterSetMode) -> None:
		"""SCPI: [SOURce<HW>]:LIST:DWELl:MODE \n
		Snippet: driver.source.listPy.dwell.set_mode(dwell_mode = enums.ParameterSetMode.GLOBal) \n
		Selects the dwell time mode. \n
			:param dwell_mode: LIST| GLOBal LIST Uses the dwell time, specified in the data table for each value pair individually. GLOBal Uses a constant dwell time, set with command [:SOURcehw]:LIST:DWELl.
		"""
		param = Conversions.enum_scalar_to_str(dwell_mode, enums.ParameterSetMode)
		self._core.io.write(f'SOURce<HwInstance>:LIST:DWELl:MODE {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:LIST:DWELl \n
		Snippet: value: float = driver.source.listPy.dwell.get_value() \n
		Sets the global dwell time. The instrument generates the signal with the frequency / power value pairs of each list entry
		for that particular period. See also 'Significant parameters and functions'. \n
			:return: dwell: float Range: 1E-3 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LIST:DWELl?')
		return Conversions.str_to_float(response)

	def set_value(self, dwell: float) -> None:
		"""SCPI: [SOURce<HW>]:LIST:DWELl \n
		Snippet: driver.source.listPy.dwell.set_value(dwell = 1.0) \n
		Sets the global dwell time. The instrument generates the signal with the frequency / power value pairs of each list entry
		for that particular period. See also 'Significant parameters and functions'. \n
			:param dwell: float Range: 1E-3 to 100
		"""
		param = Conversions.decimal_value_to_str(dwell)
		self._core.io.write(f'SOURce<HwInstance>:LIST:DWELl {param}')

	def clone(self) -> 'DwellCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DwellCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ag12Cls:
	"""Ag12 commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ag12", core, parent)

	def set(self, t_1_alloc_gran: enums.Granularity, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:AG12 \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.ag12.set(t_1_alloc_gran = enums.Granularity.N16, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Configures the higher layer parameter resourceAllocationType1GranularityDCI-1-2 as defined in 3GPP 38.331. \n
			:param t_1_alloc_gran: NCON| N2| N4| N8| N16 NCON Not configured. N2|N4|N8|N16 Granularity as defined by 3GPP.
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.enum_scalar_to_str(t_1_alloc_gran, enums.Granularity)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:AG12 {param}')

	# noinspection PyTypeChecker
	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> enums.Granularity:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:PDSCh:AG12 \n
		Snippet: value: enums.Granularity = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.ag12.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Configures the higher layer parameter resourceAllocationType1GranularityDCI-1-2 as defined in 3GPP 38.331. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: t_1_alloc_gran: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:AG12?')
		return Conversions.str_to_scalar_enum(response, enums.Granularity)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def get_ok(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:DME:PINPut:TRIGger:LEVel:OK \n
		Snippet: value: bool = driver.source.bb.dme.pinput.trigger.level.get_ok() \n
		Queries, if the search trigger level procedure determines a valid trigger level or not. Use this query for quick check,
		if there is a valid trigger level without running the search trigger level procedure via the following command: \n
			:return: is_trig_lev_ok: 1| ON| 0| OFF 1|ON Valid trigger level 0|OFF Invalid trigger level
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:PINPut:TRIGger:LEVel:OK?')
		return Conversions.str_to_bool(response)

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:PINPut:TRIGger:LEVel \n
		Snippet: value: float = driver.source.bb.dme.pinput.trigger.level.get_value() \n
		Queries the last measured value of the trigger power level. This level is the 50% voltage point of the first pulse of the
		external DME interrogation signal. \n
			:return: trigger_level: float Range: -200 to 200
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:PINPut:TRIGger:LEVel?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MbeaconCls:
	"""Mbeacon commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mbeacon", core, parent)

	@property
	def marker(self):
		"""marker commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:[ILS]:MBEacon:PRESet \n
		Snippet: driver.source.ils.mbeacon.preset() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:ILS:MBEacon:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:[ILS]:MBEacon:PRESet \n
		Snippet: driver.source.ils.mbeacon.preset_with_opc() \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:ILS:MBEacon:PRESet', opc_timeout_ms)

	def clone(self) -> 'MbeaconCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MbeaconCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MtiaCls:
	"""Mtia commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mtia", core, parent)

	def set(self, nprs_muting_info_a: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:MTIA \n
		Snippet: driver.source.bb.eutra.downlink.niot.nprs.mtia.set(nprs_muting_info_a = rawAbc, bitcount = 1) \n
		Sets the nprs-MutingInfoA/nprs-MutingInfoB parameter, required if muting is used for the NPRS part A (and Part B)
		configurations. \n
			:param nprs_muting_info_a: numeric '1' indicates that the NPRS is transmitted in the corresponding occasion; a '0' indicates a muted NPRS.
			:param bitcount: integer Sets the length of the periodically repeating NPRS bit sequence in number of NPRS position occurrences. Allowed are the following values: 2, 4, 8 or 16 Range: 2 to 16
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('nprs_muting_info_a', nprs_muting_info_a, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:MTIA {param}'.rstrip())

	# noinspection PyTypeChecker
	class MtiaStruct(StructBase):
		"""Response structure. Fields: \n
			- Nprs_Muting_Info_A: str: No parameter help available
			- Bitcount: int: integer Sets the length of the periodically repeating NPRS bit sequence in number of NPRS position occurrences. Allowed are the following values: 2, 4, 8 or 16 Range: 2 to 16"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Nprs_Muting_Info_A'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Nprs_Muting_Info_A: str = None
			self.Bitcount: int = None

	def get(self) -> MtiaStruct:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:NPRS:MTIA \n
		Snippet: value: MtiaStruct = driver.source.bb.eutra.downlink.niot.nprs.mtia.get() \n
		Sets the nprs-MutingInfoA/nprs-MutingInfoB parameter, required if muting is used for the NPRS part A (and Part B)
		configurations. \n
			:return: structure: for return value, see the help for MtiaStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:NPRS:MTIA?', self.__class__.MtiaStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisplayCls:
	"""Display commands group definition. 40 total commands, 8 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("display", core, parent)

	@property
	def antenna(self):
		"""antenna commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import AntennaCls
			self._antenna = AntennaCls(self._core, self._cmd_group)
		return self._antenna

	@property
	def channels(self):
		"""channels commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_channels'):
			from .Channels import ChannelsCls
			self._channels = ChannelsCls(self._core, self._cmd_group)
		return self._channels

	@property
	def map(self):
		"""map commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_map'):
			from .Map import MapCls
			self._map = MapCls(self._core, self._cmd_group)
		return self._map

	@property
	def power(self):
		"""power commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def stream(self):
		"""stream commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stream'):
			from .Stream import StreamCls
			self._stream = StreamCls(self._core, self._cmd_group)
		return self._stream

	@property
	def tracks(self):
		"""tracks commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tracks'):
			from .Tracks import TracksCls
			self._tracks = TracksCls(self._core, self._cmd_group)
		return self._tracks

	@property
	def trajectory(self):
		"""trajectory commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_trajectory'):
			from .Trajectory import TrajectoryCls
			self._trajectory = TrajectoryCls(self._core, self._cmd_group)
		return self._trajectory

	@property
	def vehicle(self):
		"""vehicle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vehicle'):
			from .Vehicle import VehicleCls
			self._vehicle = VehicleCls(self._core, self._cmd_group)
		return self._vehicle

	def set(self, display_type: enums.MonitorDisplayType, monitorPane=repcap.MonitorPane.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay \n
		Snippet: driver.source.bb.gnss.monitor.display.set(display_type = enums.MonitorDisplayType.ATTitude, monitorPane = repcap.MonitorPane.Default) \n
		Switches between the available views. \n
			:param display_type: SKY| MAP| POWer| TRAJectory| ATTitude| TRACks| CHANnels
			:param monitorPane: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')
		"""
		param = Conversions.enum_scalar_to_str(display_type, enums.MonitorDisplayType)
		monitorPane_cmd_val = self._cmd_group.get_repcap_cmd_value(monitorPane, repcap.MonitorPane)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:MONitor{monitorPane_cmd_val}:DISPlay {param}')

	# noinspection PyTypeChecker
	def get(self, monitorPane=repcap.MonitorPane.Default) -> enums.MonitorDisplayType:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay \n
		Snippet: value: enums.MonitorDisplayType = driver.source.bb.gnss.monitor.display.get(monitorPane = repcap.MonitorPane.Default) \n
		Switches between the available views. \n
			:param monitorPane: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')
			:return: display_type: SKY| MAP| POWer| TRAJectory| ATTitude| TRACks| CHANnels"""
		monitorPane_cmd_val = self._cmd_group.get_repcap_cmd_value(monitorPane, repcap.MonitorPane)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:MONitor{monitorPane_cmd_val}:DISPlay?')
		return Conversions.str_to_scalar_enum(response, enums.MonitorDisplayType)

	def clone(self) -> 'DisplayCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DisplayCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IsPyCls:
	"""IsPy commands group definition. 17 total commands, 0 Subgroups, 17 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("isPy", core, parent)

	# noinspection PyTypeChecker
	def get_band(self) -> enums.Band:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:BAND \n
		Snippet: value: enums.Band = driver.source.bb.nr5G.tcw.isPy.get_band() \n
		Set the frequency band (n1 to n86) for the interfering signal. \n
			:return: band: N1| N2| N3| N5| N7| N8| N12| N20| N25| N28| N34| N38| N39| N40| N41| N50| N51| N66| N70| N71| N74| N75| N76| N77| N78| N79| N80| N81| N82| N83| N84| N86
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:BAND?')
		return Conversions.str_to_scalar_enum(response, enums.Band)

	def set_band(self, band: enums.Band) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:BAND \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_band(band = enums.Band.N1) \n
		Set the frequency band (n1 to n86) for the interfering signal. \n
			:param band: N1| N2| N3| N5| N7| N8| N12| N20| N25| N28| N34| N38| N39| N40| N41| N50| N51| N66| N70| N71| N74| N75| N76| N77| N78| N79| N80| N81| N82| N83| N84| N86
		"""
		param = Conversions.enum_scalar_to_str(band, enums.Band)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:BAND {param}')

	# noinspection PyTypeChecker
	def get_chbw(self) -> enums.Nr5Gcbw:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:CHBW \n
		Snippet: value: enums.Nr5Gcbw = driver.source.bb.nr5G.tcw.isPy.get_chbw() \n
		Queries the channel bandwidth of the interfering signal. \n
			:return: isch_bw: BW5 | BW10 | BW15 | BW20 | BW25 | BW30 | BW35 | BW40 | BW45 | BW50 | BW60 | BW70 | BW80 | BW90 | BW100 | BW200 | BW400 | BW800 | BW1600 | BW2000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:CHBW?')
		return Conversions.str_to_scalar_enum(response, enums.Nr5Gcbw)

	def get_clid(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:CLID \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_clid() \n
		No command help available \n
			:return: is_cell_id: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:CLID?')
		return Conversions.str_to_int(response)

	def set_clid(self, is_cell_id: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:CLID \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_clid(is_cell_id = 1) \n
		No command help available \n
			:param is_cell_id: No help available
		"""
		param = Conversions.decimal_value_to_str(is_cell_id)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:CLID {param}')

	def get_distance(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:DISTance \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_distance() \n
		Sets the distance between the test object and test antenna injecting the interferer signal. \n
			:return: distance: integer Range: 1 to 300
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:DISTance?')
		return Conversions.str_to_int(response)

	def set_distance(self, distance: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:DISTance \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_distance(distance = 1) \n
		Sets the distance between the test object and test antenna injecting the interferer signal. \n
			:param distance: integer Range: 1 to 300
		"""
		param = Conversions.decimal_value_to_str(distance)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:DISTance {param}')

	# noinspection PyTypeChecker
	def get_duplex(self) -> enums.EutraDuplexMode:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:DUPLex \n
		Snippet: value: enums.EutraDuplexMode = driver.source.bb.nr5G.tcw.isPy.get_duplex() \n
		The duplexing mechanism used for the interfering signal can be switched between FDD and TDD. \n
			:return: is_duplexing: FDD| TDD
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:DUPLex?')
		return Conversions.str_to_scalar_enum(response, enums.EutraDuplexMode)

	def set_duplex(self, is_duplexing: enums.EutraDuplexMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:DUPLex \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_duplex(is_duplexing = enums.EutraDuplexMode.FDD) \n
		The duplexing mechanism used for the interfering signal can be switched between FDD and TDD. \n
			:param is_duplexing: FDD| TDD
		"""
		param = Conversions.enum_scalar_to_str(is_duplexing, enums.EutraDuplexMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:DUPLex {param}')

	# noinspection PyTypeChecker
	def get_fr_shift(self) -> enums.FreqShift:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:FRSHift \n
		Snippet: value: enums.FreqShift = driver.source.bb.nr5G.tcw.isPy.get_fr_shift() \n
		No command help available \n
			:return: is_freq_shift: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:FRSHift?')
		return Conversions.str_to_scalar_enum(response, enums.FreqShift)

	def set_fr_shift(self, is_freq_shift: enums.FreqShift) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:FRSHift \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_fr_shift(is_freq_shift = enums.FreqShift.FS0) \n
		No command help available \n
			:param is_freq_shift: No help available
		"""
		param = Conversions.enum_scalar_to_str(is_freq_shift, enums.FreqShift)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:FRSHift {param}')

	# noinspection PyTypeChecker
	def get_if_type(self) -> enums.InterfererTypeNr:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:IFTYpe \n
		Snippet: value: enums.InterfererTypeNr = driver.source.bb.nr5G.tcw.isPy.get_if_type() \n
		No command help available \n
			:return: interferer_type_1: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:IFTYpe?')
		return Conversions.str_to_scalar_enum(response, enums.InterfererTypeNr)

	def set_if_type(self, interferer_type_1: enums.InterfererTypeNr) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:IFTYpe \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_if_type(interferer_type_1 = enums.InterfererTypeNr.CW) \n
		No command help available \n
			:param interferer_type_1: No help available
		"""
		param = Conversions.enum_scalar_to_str(interferer_type_1, enums.InterfererTypeNr)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:IFTYpe {param}')

	def get_nrblock(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:NRBLock \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_nrblock() \n
		No command help available \n
			:return: is_num_rb: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:NRBLock?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_ofn(self) -> enums.OffsetFactorN:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:OFN \n
		Snippet: value: enums.OffsetFactorN = driver.source.bb.nr5G.tcw.isPy.get_ofn() \n
		Set the offset factor for the interfering signal. \n
			:return: offset_factor_n: OFN_1| OFN_2| OFN_3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:OFN?')
		return Conversions.str_to_scalar_enum(response, enums.OffsetFactorN)

	def set_ofn(self, offset_factor_n: enums.OffsetFactorN) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:OFN \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_ofn(offset_factor_n = enums.OffsetFactorN.OFN_1) \n
		Set the offset factor for the interfering signal. \n
			:param offset_factor_n: OFN_1| OFN_2| OFN_3
		"""
		param = Conversions.enum_scalar_to_str(offset_factor_n, enums.OffsetFactorN)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:OFN {param}')

	def get_plevel(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:PLEVel \n
		Snippet: value: float = driver.source.bb.nr5G.tcw.isPy.get_plevel() \n
		Queries the power level of the interfering signal. \n
			:return: is_pow_level: float Range: -145 to 20, Unit: dBm
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:PLEVel?')
		return Conversions.str_to_float(response)

	def get_rbc_frequency(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:RBCFrequency \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_rbc_frequency() \n
		No command help available \n
			:return: is_rb_center_freq: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:RBCFrequency?')
		return Conversions.str_to_int(response)

	def get_rb_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:RBOFfset \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_rb_offset() \n
		No command help available \n
			:return: is_rb_offset: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:RBOFfset?')
		return Conversions.str_to_int(response)

	def set_rb_offset(self, is_rb_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:RBOFfset \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_rb_offset(is_rb_offset = 1) \n
		No command help available \n
			:param is_rb_offset: No help available
		"""
		param = Conversions.decimal_value_to_str(is_rb_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:RBOFfset {param}')

	def get_rf_frequency(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:RFFRequency \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_rf_frequency() \n
		Queries the center frequency of the interfering signal 1 and 2. \n
			:return: is_rf_freq: integer Range: 100e+03 to 6e+09, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:RFFRequency?')
		return Conversions.str_to_int(response)

	def set_rf_frequency(self, is_rf_freq: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:RFFRequency \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_rf_frequency(is_rf_freq = 1) \n
		Queries the center frequency of the interfering signal 1 and 2. \n
			:param is_rf_freq: integer Range: 100e+03 to 6e+09, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(is_rf_freq)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:RFFRequency {param}')

	# noinspection PyTypeChecker
	def get_sc_spacing(self) -> enums.Numerology:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:SCSPacing \n
		Snippet: value: enums.Numerology = driver.source.bb.nr5G.tcw.isPy.get_sc_spacing() \n
		No command help available \n
			:return: is_scs: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:SCSPacing?')
		return Conversions.str_to_scalar_enum(response, enums.Numerology)

	# noinspection PyTypeChecker
	def get_tmodel(self) -> enums.TestModel:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:TMODel \n
		Snippet: value: enums.TestModel = driver.source.bb.nr5G.tcw.isPy.get_tmodel() \n
		Shows the test model set for the test case. The NR-TMs for FR1 are defined in TS 38.141-1 section 4.9.2. \n
			:return: test_model: TM1_1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:TMODel?')
		return Conversions.str_to_scalar_enum(response, enums.TestModel)

	# noinspection PyTypeChecker
	def get_trequire(self) -> enums.TestRequire:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:TREQuire \n
		Snippet: value: enums.TestRequire = driver.source.bb.nr5G.tcw.isPy.get_trequire() \n
		No command help available \n
			:return: is_test_require: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:TREQuire?')
		return Conversions.str_to_scalar_enum(response, enums.TestRequire)

	def set_trequire(self, is_test_require: enums.TestRequire) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:TREQuire \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_trequire(is_test_require = enums.TestRequire.BLPE) \n
		No command help available \n
			:param is_test_require: No help available
		"""
		param = Conversions.enum_scalar_to_str(is_test_require, enums.TestRequire)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:TREQuire {param}')

	def get_ue_id(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:UEID \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.isPy.get_ue_id() \n
		Sets the UE ID/n_RNTI for the interfering signal. \n
			:return: isu_eid: integer Range: 0 to 65535
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:IS:UEID?')
		return Conversions.str_to_int(response)

	def set_ue_id(self, isu_eid: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:IS:UEID \n
		Snippet: driver.source.bb.nr5G.tcw.isPy.set_ue_id(isu_eid = 1) \n
		Sets the UE ID/n_RNTI for the interfering signal. \n
			:param isu_eid: integer Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(isu_eid)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:IS:UEID {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EditCls:
	"""Edit commands group definition. 7 total commands, 3 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("edit", core, parent)

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import ApplyCls
			self._apply = ApplyCls(self._core, self._cmd_group)
		return self._apply

	@property
	def device(self):
		"""device commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_device'):
			from .Device import DeviceCls
			self._device = DeviceCls(self._core, self._cmd_group)
		return self._device

	@property
	def remove(self):
		"""remove commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remove'):
			from .Remove import RemoveCls
			self._remove = RemoveCls(self._core, self._cmd_group)
		return self._remove

	def get_alias(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:ALIas \n
		Snippet: value: str = driver.source.areGenerator.external.remote.edit.get_alias() \n
		No command help available \n
			:return: symbolic_name: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:ALIas?')
		return trim_str_response(response)

	def set_alias(self, symbolic_name: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:ALIas \n
		Snippet: driver.source.areGenerator.external.remote.edit.set_alias(symbolic_name = 'abc') \n
		No command help available \n
			:param symbolic_name: No help available
		"""
		param = Conversions.value_to_quoted_str(symbolic_name)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:ALIas {param}')

	def get_hostname(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:HOSTname \n
		Snippet: value: str = driver.source.areGenerator.external.remote.edit.get_hostname() \n
		No command help available \n
			:return: hostname_or_ip: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:HOSTname?')
		return trim_str_response(response)

	def set_hostname(self, hostname_or_ip: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:HOSTname \n
		Snippet: driver.source.areGenerator.external.remote.edit.set_hostname(hostname_or_ip = 'abc') \n
		No command help available \n
			:param hostname_or_ip: No help available
		"""
		param = Conversions.value_to_quoted_str(hostname_or_ip)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:HOSTname {param}')

	def get_iselect(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:ISELect \n
		Snippet: value: str = driver.source.areGenerator.external.remote.edit.get_iselect() \n
		No command help available \n
			:return: instrument_name: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:ISELect?')
		return trim_str_response(response)

	def set_iselect(self, instrument_name: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:ISELect \n
		Snippet: driver.source.areGenerator.external.remote.edit.set_iselect(instrument_name = 'abc') \n
		No command help available \n
			:param instrument_name: No help available
		"""
		param = Conversions.value_to_quoted_str(instrument_name)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:ISELect {param}')

	# noinspection PyTypeChecker
	def get_rchannel(self) -> enums.RcConnType:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:RCHannel \n
		Snippet: value: enums.RcConnType = driver.source.areGenerator.external.remote.edit.get_rchannel() \n
		No command help available \n
			:return: remote_channel: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:RCHannel?')
		return Conversions.str_to_scalar_enum(response, enums.RcConnType)

	def set_rchannel(self, remote_channel: enums.RcConnType) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:EXTernal:REMote:EDIT:RCHannel \n
		Snippet: driver.source.areGenerator.external.remote.edit.set_rchannel(remote_channel = enums.RcConnType.FRONtend) \n
		No command help available \n
			:param remote_channel: No help available
		"""
		param = Conversions.enum_scalar_to_str(remote_channel, enums.RcConnType)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:EXTernal:REMote:EDIT:RCHannel {param}')

	def clone(self) -> 'EditCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EditCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class S64QamCls:
	"""S64Qam commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("s64Qam", core, parent)

	def set(self, s_64_qam: bool, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:S64Qam \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.s64Qam.set(s_64_qam = False, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Enables/disables UE support of 64QAM. This command is enabled only for HS-SCCH Type 1 (normal operation) and 16QAM
		modulation. In case this parameter is disabled, i.e. the UE does not support 64QAM, the xccs,7 bit is used for
		channelization information. \n
			:param s_64_qam: ON| OFF
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.bool_to_str(s_64_qam)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:S64Qam {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:S64Qam \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.s64Qam.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Enables/disables UE support of 64QAM. This command is enabled only for HS-SCCH Type 1 (normal operation) and 16QAM
		modulation. In case this parameter is disabled, i.e. the UE does not support 64QAM, the xccs,7 bit is used for
		channelization information. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: s_64_qam: ON| OFF"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:S64Qam?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoderCls:
	"""Coder commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coder", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.BbCodMode:
		"""SCPI: [SOURce<HW>]:BB:CODer:MODE \n
		Snippet: value: enums.BbCodMode = driver.source.bb.coder.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:CODer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.BbCodMode)

	def set_mode(self, mode: enums.BbCodMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:CODer:MODE \n
		Snippet: driver.source.bb.coder.set_mode(mode = enums.BbCodMode.BBIN) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.BbCodMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:CODer:MODE {param}')
